package cz.frantovo.abcDrupal;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Date;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Řídící třída, stará se o konverzi z databáze Drupalu do databáze ABC.
 * @author fiki
 */
public class Konvertor {

    private static final Logger log = Logger.getLogger(Konvertor.class.getSimpleName());
    private PosluchacLogu posluchacLogu;
    private String jdbcZdroj;
    private String jdbcCil;
    private Connection dbZdroj;
    private Connection dbCil;

    public Konvertor(String jdbcZdroj, String jdbcCil, PosluchacLogu posluchacLogu) {
	this.jdbcZdroj = jdbcZdroj;
	this.jdbcCil = jdbcCil;
	this.posluchacLogu = posluchacLogu;
    }

    public void konvertuj() {
	vypis("Začíná migrace");


	try {
	    nastavDBspojeni();
	} catch (SQLException e) {
	    vypis("Chyba při připojování k databázím.");
	    log.log(Level.SEVERE, "Chyba při připojování k databázím.", e);
	    vypis("Končím.");
	    return;
	}


	vypis("Migrace dokončena");
    }

    /**
     * Připojí databáze a zkontroluje SQL dotazem, že jsou v pořádku.
     * @throws SQLException
     */
    private void nastavDBspojeni() throws SQLException {
	dbZdroj = DriverManager.getConnection(jdbcZdroj);
	dbCil = DriverManager.getConnection(jdbcCil);

	PreparedStatement sqlZdroj = dbZdroj.prepareStatement("SELECT count(*) FROM node");
	ResultSet rsZdroj = sqlZdroj.executeQuery();
	rsZdroj.next();
	int pocetZdroj = rsZdroj.getInt(1);
	log.log(Level.INFO, "Počet záznamů v tabulce „node“ ve zdrojové DB: " + pocetZdroj);
	zavri(null, sqlZdroj, rsZdroj);

	PreparedStatement sqlCil = dbCil.prepareStatement("SELECT count(*) FROM polozka");
	ResultSet rsCil = sqlCil.executeQuery();
	rsCil.next();
	int pocetCil = rsCil.getInt(1);
	log.log(Level.INFO, "Počet záznamů v tabulce „polozka“ v cílové DB: " + pocetCil);
	zavri(null, sqlCil, rsCil);
    }

    private void vypis(String zprava) {
	if (posluchacLogu != null) {
	    posluchacLogu.vypis(new Date() + " " + zprava);
	}
    }

    /**
     * Zavře všechno
     * @param spojeni DB spojení
     * @param prikaz DB dotaz
     * @param vysledek DB výsledek
     */
    protected static void zavri(Connection spojeni, Statement prikaz, ResultSet vysledek) {
        if (vysledek != null) {
            try {
                vysledek.close();
            } catch (Exception e) {
            }
        }
        if (prikaz != null) {
            try {
                prikaz.close();
            } catch (Exception e) {
            }
        }
        if (spojeni != null) {
            try {
                spojeni.close();
            } catch (Exception e) {
            }
        }
    }
}
